@@ -32,6 +32,7 @@ from ..core.data.util import dask_array_module
 from ..core.util import (
     datetime_types,
     dt_to_int,
+    dtype_kind,
     group_sanitizer,
     is_cupy_array,
     is_dask_array,
@@ -1065,16 +1066,23 @@ class interpolate_curve(Operation):
 
     _per_element = True
 
+    @staticmethod
+    def _get_dtype(obj):
+        if dtype_kind(obj) == "O":
+            # Handle non-numpy objects like Pandas 3.0 StringArray
+            return "O"
+        return obj.dtype
+
     @classmethod
     def pts_to_prestep(cls, x, values):
         steps = np.zeros(2 * len(x) - 1)
-        value_steps = tuple(np.empty(2 * len(x) - 1, dtype=v.dtype) for v in values)
+        value_steps = tuple(np.empty(2 * len(x) - 1, dtype=cls._get_dtype(v)) for v in values)
 
         steps[0::2] = x
         steps[1::2] = steps[0:-2:2]
 
         val_arrays = []
-        for v, s in zip(values, value_steps, strict=None):
+        for v, s in zip(values, value_steps, strict=True):
             s[0::2] = v
             s[1::2] = s[2::2]
             val_arrays.append(s)
@@ -1084,13 +1092,13 @@ class interpolate_curve(Operation):
     @classmethod
     def pts_to_midstep(cls, x, values):
         steps = np.zeros(2 * len(x))
-        value_steps = tuple(np.empty(2 * len(x), dtype=v.dtype) for v in values)
+        value_steps = tuple(np.empty(2 * len(x), dtype=cls._get_dtype(v)) for v in values)
 
         steps[1:-1:2] = steps[2::2] = x[:-1] + (x[1:] - x[:-1])/2
         steps[0], steps[-1] = x[0], x[-1]
 
         val_arrays = []
-        for v, s in zip(values, value_steps, strict=None):
+        for v, s in zip(values, value_steps, strict=True):
             s[0::2] = v
             s[1::2] = s[0::2]
             val_arrays.append(s)
@@ -1100,13 +1108,13 @@ class interpolate_curve(Operation):
     @classmethod
     def pts_to_poststep(cls, x, values):
         steps = np.zeros(2 * len(x) - 1)
-        value_steps = tuple(np.empty(2 * len(x) - 1, dtype=v.dtype) for v in values)
+        value_steps = tuple(np.empty(2 * len(x) - 1, dtype=cls._get_dtype(v)) for v in values)
 
         steps[0::2] = x
         steps[1::2] = steps[2::2]
 
         val_arrays = []
-        for v, s in zip(values, value_steps, strict=None):
+        for v, s in zip(values, value_steps, strict=True):
             s[0::2] = v
             s[1::2] = s[0:-2:2]
             val_arrays.append(s)
