@@ -3,14 +3,19 @@ Unit tests of the helper functions in core.utils
 """
 import datetime
 import math
+import os
 import unittest
 from itertools import product
+from pathlib import Path
+from zoneinfo import ZoneInfo
 
+import narwhals.stable.v2 as nw
 import numpy as np
 import pandas as pd
 import pytest
 
 from holoviews import Dimension, Element
+from holoviews.core import util
 from holoviews.core.util import (
     closest_match,
     compute_density,
@@ -20,6 +25,7 @@ from holoviews.core.util import (
     deephash,
     dimension_range,
     dt_to_int,
+    dtype_kind,
     find_range,
     get_path,
     is_nan,
@@ -34,12 +40,27 @@ from holoviews.core.util import (
     unique_array,
     wrap_tuple_streams,
 )
+from holoviews.core.util.types import masked_types
 from holoviews.element.comparison import ComparisonTestCase
 from holoviews.streams import PointerXY
 
 sanitize_identifier = sanitize_identifier_fn.instance()
 
 
+@pytest.fixture
+def with_pandas(request, monkeypatch):
+  """Fixture to control pandas availability"""
+  if request.param:
+      pytest.importorskip("pandas")
+  else:
+      monkeypatch.setattr(util, 'pd', None)
+
+
+def with_and_without_pandas(func):
+  """Decorator to test both with and without pandas"""
+  return pytest.mark.parametrize("with_pandas", [True, False], indirect=True, ids=["with_pandas", "without_pandas"])(func)
+
+
 class TestDeepHash(ComparisonTestCase):
     """
     Tests of deephash function used for memoization.
@@ -569,8 +590,7 @@ class TestDatetimeUtils(unittest.TestCase):
         self.assertEqual(drange[-1], end-np.timedelta64(50, 'ms'))
 
     def test_timezone_to_int(self):
-        import pytz
-        timezone = pytz.timezone("Europe/Copenhagen")
+        timezone = ZoneInfo("Europe/Copenhagen")
 
         values = [
             datetime.datetime(2021, 4, 8, 12, 0, 0, 0),
@@ -676,6 +696,15 @@ class TestNumericUtilities(ComparisonTestCase):
         dt64 = np.array([*dts, np.datetime64('NaT')])
         self.assertEqual(isfinite(dt64), np.array([True, True, True, False]))
 
+    def test_isfinite_masked_numpy(self):
+        masked = np.ma.core.MaskedArray([1, 2, 3], mask=[False, True, False])
+        assert isinstance(masked, masked_types)
+        assert list(isfinite(masked)) == [True, False, True]
+
+    def test_isfinite_masked_pandas(self):
+        masked = pd.array([1, None, 3], dtype="Int64")
+        assert isinstance(masked, masked_types)
+        assert list(isfinite(masked)) == [True, False, True]
 
 
 class TestComputeEdges(ComparisonTestCase):
@@ -799,7 +828,7 @@ class TestClosestMatch(ComparisonTestCase):
         self.assertEqual(closest_match(spec, specs), None)
 
 
-def test_seach_indices_dtype_object():
+def test_search_indices_dtype_object():
     values = np.array(["c0", "c0", np.nan], dtype=object)
     source = np.array(["c0", np.nan], dtype=object)
     search_indices(values, source)
@@ -846,3 +875,127 @@ def test_is_null_or_na_scalar_polars():
     assert is_null_or_na_scalar(pl.Null)
     assert not is_null_or_na_scalar(pl.DataFrame([1, 2]))
     assert not is_null_or_na_scalar(pl.LazyFrame([1, 2]))
+
+
+@pytest.mark.parametrize(["data", "dtype", "expected_kind"], [
+    # Boolean
+    ([True, False, True], 'bool', 'b'),
+
+    # Integer types
+    ([1, 2, 3], 'int8', 'i'),
+    ([1, 2, 3], 'int16', 'i'),
+    ([1, 2, 3], 'int32', 'i'),
+    ([1, 2, 3], 'int64', 'i'),
+    ([1, 2, 3], 'uint8', 'u'),
+    ([1, 2, 3], 'uint16', 'u'),
+    ([1, 2, 3], 'uint32', 'u'),
+    ([1, 2, 3], 'uint64', 'u'),
+
+    # Float types
+    pytest.param([1.1, 2.2, 3.3], 'float16', 'f', marks=pytest.mark.xfail(reason="narwhals don't support float16")),
+    ([1.1, 2.2, 3.3], 'float32', 'f'),
+    ([1.1, 2.2, 3.3], 'float64', 'f'),
+
+    # Datetime and timedelta
+    (pd.to_datetime(['2021-01-01', '2021-01-02', '2021-01-03']), None, 'M'),
+    (pd.to_timedelta(['1 days', '2 days', '3 days']), None, 'm'),
+
+    # Categorical
+    (pd.Categorical(['A', 'B', 'A']), None, 'O'),
+
+    # Object (mixed types)
+    ([1, 'a', None], None, 'O'),
+
+    # String types
+    pytest.param(['x', 'y', 'z'], 'string[python]', 'U', marks=pytest.mark.xfail(reason="pandas dtype is object")),
+    pytest.param(['x', 'y', 'z'], 'object', 'O', marks=pytest.mark.xfail(reason="narwhals dtype is string")),
+])
+def test_dtype_kind_pandas_narwhals_consistency(data, dtype, expected_kind):
+    """Test dtype_kind gives same results for pandas and narwhals DataFrames"""
+    pd_df = pd.DataFrame({'col': data})
+    if dtype is not None:
+        pd_df = pd_df.astype({'col': dtype})
+    nw_df = nw.from_native(pd_df)
+
+    pd_kind = dtype_kind(pd_df['col'])
+    nw_kind = dtype_kind(nw_df['col'])
+
+    assert pd_kind == expected_kind
+    assert nw_kind == expected_kind
+
+
+def test_dtype_kind_usage_count():
+    holoviews_path = Path(__file__).parents[2]
+    file_counts = {}
+    for py_file in holoviews_path.rglob('*.py'):
+        rel_path = py_file.relative_to(holoviews_path)
+        if '__pycache__' in rel_path.parts or 'tests' in rel_path.parts:
+            continue
+
+        with open(py_file, encoding='utf-8') as f:
+            content = f.read()
+            count = content.count('dtype.kind')
+
+        if count > 0:
+            file_counts[str(rel_path).replace(os.sep, "/")] = count
+
+    expected_files = {'core/util/__init__.py': 1}
+    assert file_counts == expected_files, "Don't use dtype.kind, use dtype_kind"
+
+
+@with_and_without_pandas
+@pytest.mark.parametrize(
+    ["test_input","expected_output"],
+    [
+        (np.array([3, 1, 2, 1, 3, 4, 2]), np.array([3, 1, 2, 4])),
+        (np.array([1, 2, 3, 4, 5]), np.array([1, 2, 3, 4, 5])),
+        (np.array([5, 5, 5, 5]), np.array([5])),
+        (np.array([42]), np.array([42])),
+        (np.array(['b', 'a', 'c', 'a', 'b']), np.array(['b', 'a', 'c'])),
+        (np.array([1.5, 2.3, 1.5, 3.7, 2.3]), np.array([1.5, 2.3, 3.7])),
+        (np.array([1, 'a', 2, 'a', 1, 'b'], dtype=object), np.array([1, 'a', 2, 'b'], dtype=object)),
+        (np.array([]), np.array([])),
+], ids=[
+    "numeric_with_duplicates",
+    "already_unique",
+    "all_same",
+    "single_element",
+    "string_array",
+    "float_array",
+    "object_array_mixed_types",
+    "empty_array",
+])
+def test_unique(test_input, expected_output, with_pandas, monkeypatch):
+    result = util._unique(test_input)
+    np.testing.assert_array_equal(result, expected_output)
+
+
+@with_and_without_pandas
+@pytest.mark.parametrize(["test_input" ,"expected_output"], [
+    (np.datetime64('2023-01-15T12:30:45'), np.datetime64('2023-01-15T12:30:45')),
+    (datetime.datetime(2023, 1, 15, 12, 30, 45), np.datetime64('2023-01-15T12:30:45', 'ns')),
+    (datetime.date(2023, 1, 15), np.datetime64('2023-01-15T00:00:00', 'ns')),
+    ('2023-01-15T12:30:45', np.datetime64('2023-01-15T12:30:45', 'ns')),
+    ('2023-01-15', np.datetime64('2023-01-15T00:00:00', 'ns')),
+    ('2023/01/15', np.datetime64('2023-01-15T00:00:00', 'ns')),
+    (datetime.datetime(2023, 1, 15, 12, 30, 45, tzinfo=datetime.timezone.utc), np.datetime64('2023-01-15T12:30:45', 'ns')),
+    (
+        datetime.datetime(
+            2023, 1, 15, 17, 30, 45, tzinfo=datetime.timezone(datetime.timedelta(hours=5))
+        ),
+        np.datetime64('2023-01-15T12:30:45', 'ns'),
+    )],
+    ids=[
+    "numpy_datetime64",
+    "python_datetime",
+    "python_date",
+    "string_iso_format",
+    "string_simple_date",
+    "string_slash_format",
+    "timezone_aware",
+    "timezone_conversion",
+])
+def test_parse_datetime(test_input, expected_output, with_pandas, monkeypatch):
+    result = util.parse_datetime(test_input)
+    assert isinstance(result, np.datetime64)
+    assert result == expected_output
